#[non_exhaustive]pub enum PacketData {
RawTx(Vec<u8>),
RawRx(Vec<u8>),
RawError(Vec<u8>, String),
}Expand description
Raw captured traffic — bytes that moved across the wire at a specific instant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RawTx(Vec<u8>)
Bytes successfully written to the transport.
RawRx(Vec<u8>)
Bytes successfully read from the transport.
RawError(Vec<u8>, String)
Bytes received before a read error occurred, with the error message.